# The Everything Library

![Version](https://img.shields.io/badge/version-0.0.1-blue)
![Python](https://img.shields.io/badge/python-3.9%2B-green)

## Description 
This Python Library will have a LOT of different helper functions and classes that you can use for your own projects.

# Installation
How to install the library 
```bash
pip install theeverythinglibrary
```

# Features
## Current features
### Encryption
- Symmetric encryption
- Asymmetric encryption
- Full key management

### Encoding
- Base64 encoding and decoding
- Hex encoding and decoding
- Binary encoding and decoding

# History

0.0.1 (2023-08-26)
------------------

* Public on PyPi (pip install the-everything-library)

0.0.2 - 0.0.4 (2023-08-26)
------------------

* Fixing upload
